@@ -150,17 +150,13 @@ void crop_sens(const long dims[DIMS], complex float* ptr, bool soft, float crth,
  */
 static float sure_crop(float var, const long evec_dims[5], complex float* evec_data, complex float* eptr, const long calreg_dims[4], const complex float* calreg)
 {
-	// Must be in ascending order.
-        float start = 0.7;
-        float delta = 0.01;
-
-	long num_cvals = (long) (((1 - delta - start)/delta) + 1);
 	long num_maps = evec_dims[4];
 
 	// Construct low-resolution image
 	long im_dims[5];
 	md_select_dims(5, 15, im_dims, evec_dims);
-	complex float* im = md_alloc(5, im_dims, CFL_SIZE);
+	complex float* im = md_alloc_sameplace(5, im_dims, CFL_SIZE, calreg);
+	md_clear(5, im_dims, im, CFL_SIZE);
 	md_resize_center(5, im_dims, im, calreg_dims, calreg, CFL_SIZE);
 	ifftuc(5, im_dims, FFT_FLAGS, im, im);
 
@@ -170,31 +166,31 @@ static float sure_crop(float var, const long evec_dims[5], complex float* evec_d
 	cropdims[4] = num_maps;
 
 	// Eigenvectors (M)
-	complex float* M = md_alloc(5, evec_dims, CFL_SIZE);
+	complex float* M = md_alloc_sameplace(5, evec_dims, CFL_SIZE, calreg);
 	md_copy(5, evec_dims, M, evec_data, CFL_SIZE);
 
 	// Temporary eigenvector holder to hold low resolution maps
-	complex float* LM = md_alloc(5, evec_dims, CFL_SIZE);
+	complex float* LM = md_alloc_sameplace(5, evec_dims, CFL_SIZE, calreg);
 	// Temporary holder for projection calreg
-	complex float* TC = md_alloc(5, calreg_dims, CFL_SIZE);
+	complex float* TC = md_alloc_sameplace(5, calreg_dims, CFL_SIZE, calreg);
 	// Temporary holder to hold low resolution calib maps
-	complex float* CM = md_alloc(5, cropdims, CFL_SIZE);
+	complex float* CM = md_alloc_sameplace(5, cropdims, CFL_SIZE, calreg);
 
 	// Eigenvalues (W)
 	long W_dims[5];
 	md_select_dims(5, 23, W_dims, evec_dims);
-	complex float* W = md_alloc(5, W_dims, CFL_SIZE);
+	complex float* W = md_alloc_sameplace(5, W_dims, CFL_SIZE, calreg);
 	md_copy(5, W_dims, W, eptr, CFL_SIZE);
 
 	// Place holder for the inner product result
-	complex float* ip = md_alloc(5, W_dims, CFL_SIZE);
+	complex float* ip = md_alloc_sameplace(5, W_dims, CFL_SIZE, calreg);
 
 	// Place holder for the projection result
-	complex float* proj = md_alloc(5, im_dims, CFL_SIZE);
+	complex float* proj = md_alloc_sameplace(5, im_dims, CFL_SIZE, calreg);
 
 	// Place holder for divergence term
 	long div_dims[5] = MD_INIT_ARRAY(5, 1);
-	complex float* div = md_alloc(5, div_dims, CFL_SIZE);
+	complex float* div = md_alloc_sameplace(5, div_dims, CFL_SIZE, calreg);
 
 	// Calculating strides.
 	long str1_ip[5];
@@ -211,7 +207,7 @@ static float sure_crop(float var, const long evec_dims[5], complex float* evec_d
 
 	md_calc_strides(5, str1_proj,    W_dims, CFL_SIZE);
 	md_calc_strides(5, str2_proj, evec_dims, CFL_SIZE);
-	md_calc_strides(5, stro_proj, im_dims, CFL_SIZE);
+	md_calc_strides(5, stro_proj,   im_dims, CFL_SIZE);
 
 	long str1_div[5];
 	long str2_div[5];
@@ -225,7 +221,6 @@ static float sure_crop(float var, const long evec_dims[5], complex float* evec_d
 	long tdims_proj[5];
 
 	for (unsigned int i = 0; i < 5; i++) {
-
 		assert((im_dims[i] == evec_dims[i]) || (1 == im_dims[i]) || (1 == evec_dims[i]));
 		assert(( W_dims[i] == evec_dims[i]) || (1 ==  W_dims[i]) || (1 == evec_dims[i]));
 
@@ -234,56 +229,63 @@ static float sure_crop(float var, const long evec_dims[5], complex float* evec_d
 	}
 
 	// Starting parameter sweep with SURE.
-	float minMSE = 0;
-	float estMSE = 0;
-	float optVal = 0;
-	float c	     = 0;
+	float mse     = -1;
+	float old_mse = 0;
 
-	for (int idx = 0; idx < num_cvals; idx++) {
+	float s = -0.1;
+	float c = 0.99;
+	long ctr1 = 0;
+	long ctr2 = 0;
+	
 
-		estMSE = 0;
-		*div   = 0;
+	debug_printf(DP_INFO, "---------------------------------------------\n");
+	debug_printf(DP_INFO, "| CTR1 | CTR2 |  Crop  |      Est. MSE      |\n");
+	debug_printf(DP_INFO, "---------------------------------------------\n");
 
-		md_clear(5,      W_dims,   ip, CFL_SIZE);
-		md_clear(5,     im_dims, proj, CFL_SIZE);
-		md_clear(5,   evec_dims,   LM, CFL_SIZE);
-		md_clear(5, calreg_dims,   TC, CFL_SIZE);
+	while (fabs(s) > 1E-4) {
+		ctr1 ++;
+		while (c < 0.999 && c > 0.001 && (ctr2 <= 1 || mse < old_mse)) {
+			ctr2 ++;
 
-		c = start + idx * delta;
+			md_clear(5,      W_dims,   ip, CFL_SIZE);
+			md_clear(5,     im_dims, proj, CFL_SIZE);
+			md_clear(5,    div_dims,  div, CFL_SIZE);
+			md_clear(5,   evec_dims,    M, CFL_SIZE);
+			md_clear(5,   evec_dims,   LM, CFL_SIZE);
+			md_clear(5, calreg_dims,   TC, CFL_SIZE);
+			md_copy(5, evec_dims, M, evec_data, CFL_SIZE);
+			old_mse = mse;
+			mse = 0;
 
-		// Cropping
-		crop_weight(evec_dims, M, crop_thresh_function, c, W);
+			crop_weight(evec_dims, M, crop_thresh_function, c, W);                   // Cropping.
+			md_zfmacc2(5,   tdims_ip,   stro_ip,   ip,   str1_ip, im,   str2_ip, M); // Projection.
+			md_zfmac2 (5, tdims_proj, stro_proj, proj, str1_proj, ip, str2_proj, M);
+			fftuc(5, im_dims, FFT_FLAGS, proj, proj);                                // Low res proj img.
+			md_resize_center(5, calreg_dims, TC, im_dims, proj, CFL_SIZE);
+			md_resize_center(5, im_dims, proj, calreg_dims, TC, CFL_SIZE);
+			ifftuc(5, im_dims, FFT_FLAGS, proj, proj);
+			for (int jdx = 0; jdx < md_calc_size(5, im_dims); jdx++)
+				mse += powf((float) (cabsf(im[jdx] - proj[jdx])), 2);
+			fftuc(5, evec_dims, FFT_FLAGS, LM, M);                                   // low-res maps .
+			md_resize_center(5, cropdims, CM, evec_dims, LM, CFL_SIZE);
+			md_resize_center(5, evec_dims, LM, cropdims, CM, CFL_SIZE);
+			ifftuc(5, evec_dims, FFT_FLAGS, LM, LM);
+			md_zfmacc2(5, evec_dims, stro_div, div, str1_div, LM, str2_div, LM);     // Calc SURE div using low res maps.
+			mse += (float) (2 * var * crealf(*div));
 
-		// Projection (stored in proj)
-		md_zfmacc2(5,   tdims_ip,   stro_ip,   ip,   str1_ip, im,   str2_ip, M);
-		md_zfmac2 (5, tdims_proj, stro_proj, proj, str1_proj, ip, str2_proj, M);
-		
-		// Construct low resolution projection image.
-		fftuc(5, im_dims, FFT_FLAGS, proj, proj);
-		md_resize_center(5, calreg_dims, TC, im_dims, proj, CFL_SIZE);
-		md_resize_center(5, im_dims, proj, calreg_dims, TC, CFL_SIZE);
-		ifftuc(5, im_dims, FFT_FLAGS, proj, proj);
-
-		for (int jdx = 0; jdx < md_calc_size(5, im_dims); jdx++)
-			estMSE += powf(cabsf(im[jdx] - proj[jdx]), 2);
-
-		// Construct low-resolution maps 
-		fftuc(5, evec_dims, FFT_FLAGS, LM, M);
-		md_resize_center(5, cropdims, CM, evec_dims, LM, CFL_SIZE);
-		md_resize_center(5, evec_dims, LM, cropdims, CM, CFL_SIZE);
-		ifftuc(5, evec_dims, FFT_FLAGS, LM, LM);
-
-		// Calculating SURE divergence using low resolution maps
-		md_zfmacc2(5, evec_dims, stro_div, div, str1_div, LM, str2_div, LM);
-
-		estMSE += 2 * var * creal(*div);
-
-		if ((0 == idx) || (estMSE < minMSE)) {
-
-			optVal = c;
-			minMSE = estMSE;
+			if (ctr2 == 1)
+				debug_printf(DP_INFO, "| %4ld | %4ld | %0.4f | %0.12e |\n", ctr1, ctr2, c, mse);
+			else
+				debug_printf(DP_INFO, "|      | %4ld | %0.4f | %0.12e |\n", ctr2, c, mse);
+			c = c + s;
 		}
+		c -= s;
+		ctr2 = 0;
+		s = -s/2;
+		c += s;
 	}
+	c = c + s;
+	debug_printf(DP_INFO, "---------------------------------------------\n");
 
 	md_free(im);
 	md_free(TC);
@@ -295,14 +297,9 @@ static float sure_crop(float var, const long evec_dims[5], complex float* evec_d
 	md_free(proj);
 	md_free(div);
 
-	// Smudge factor is to soften by little bit to improve robustness. This is to account for
-	// the sweeped thresholds possibly having a too large a step size between them and for any 
-	// other inconsistencies.
-	float smudge = 0.99;
-	debug_printf(DP_DEBUG1, "Calculated c: %.3f\n", optVal);
-	debug_printf(DP_DEBUG1, "Smudge: %.3f\n", smudge);
+	debug_printf(DP_DEBUG1, "Calculated c: %.4f\n", c);
 
-	return smudge * optVal;
+	return c;
 }
 
 
@@ -556,7 +553,7 @@ void calib2(const struct ecalib_conf* conf, const long out_dims[DIMS], complex f
 		md_zsmul(DIMS, out_dims, out_data, out_data, sqrtf((float)channels));
 	}
 
-	float c = (conf->crop > 0) ? conf->crop : sure_crop(conf->var, out_dims, out_data, eptr, calreg_dims, data);
+	float c = (conf->crop >= 0.) ? conf->crop : sure_crop(conf->var, out_dims, out_data, eptr, calreg_dims, data);
 
 	debug_printf(DP_DEBUG1, "Crop maps... (c = %.2f)\n", c);
 
