@@ -45,5 +45,5 @@ int main_carg(int argc, char* argv[])
 
 	unmap_cfl(DIMS, dims, out_data);
 	unmap_cfl(DIMS, dims, in_data);
-	exit(0);
+	return 0;
 }
