@@ -30,10 +30,9 @@
 #include "misc/types.h"
 #include "misc/mri.h"
 #include "misc/debug.h"
-#include "misc/mmio.h"
-
 
 #include "noir/model.h"
+
 #include "nlops/nlop.h"
 
 #include "recon.h"
@@ -76,10 +75,12 @@ const struct noir_conf_s noir_defaults = {
 	.b = 32.,
 	.pattern_for_each_coil = false,
 	.sms = false,
+	.cnstcoil_flags = 0u,
+	.img_space_coils = false,
 };
 
 
-void noir_recon(const struct noir_conf_s* conf, const long dims[DIMS], complex float* img, complex float* sens, complex float* ksens, const complex float* ref, const complex float* pattern, const complex float* mask, const complex float* kspace_data )
+void noir_recon(const struct noir_conf_s* conf, const long dims[DIMS], complex float* img, complex float* sens, complex float* ksens, const complex float* ref, const complex float* pattern, const complex float* mask, const complex float* kspace_data)
 {
 	struct noir_model_conf_s mconf = noir_model_conf_defaults;
 	mconf.rvc = conf->rvc;
@@ -88,6 +89,7 @@ void noir_recon(const struct noir_conf_s* conf, const long dims[DIMS], complex f
 	mconf.a = conf->a;
 	mconf.b = conf->b;
 	mconf.ptrn_flags = ~(MAPS_FLAG|COIL_FLAG);
+	mconf.cnstcoil_flags = conf->cnstcoil_flags;
 
 	if (conf->sms)
 		mconf.fft_flags |= SLICE_FLAG;
@@ -119,18 +121,29 @@ void noir_recon(const struct noir_conf_s* conf, const long dims[DIMS], complex f
 
 	complex float* xref = NULL;
 
-	if (NULL != ref) {
-
-		xref = md_alloc_sameplace(1, d1, CFL_SIZE, kspace_data);
-		md_copy(1, d1, xref, ref, CFL_SIZE);
-	}
-
 #if 1
 	struct noir_s nl = noir_create(dims, mask, pattern, &mconf);
 #else
 	struct noir_s nl = noir_create3(dims, mask, pattern, &mconf);
 	nl.nlop = nlop_flatten(nl.nlop);
 #endif
+
+	if (NULL != ref) {
+
+		xref = md_alloc_sameplace(1, d1, CFL_SIZE, kspace_data);
+
+		if (conf->img_space_coils == true) { // transform coils back to k-space
+
+				complex float* ref_buf = md_alloc(1, d1, CFL_SIZE);
+				md_copy(1, d1, ref_buf, ref, CFL_SIZE);
+				ifftmod(DIMS, coil_dims, mconf.fft_flags, ref_buf + skip, ref + skip);
+				noir_back_coils(nl.linop, ref_buf + skip, ref_buf + skip);
+				md_copy(1, d1, xref, ref_buf, CFL_SIZE);
+				md_free(ref_buf);
+
+		} else 
+			md_copy(1, d1, xref, ref, CFL_SIZE);
+	}
 	struct iter3_irgnm_conf irgnm_conf = iter3_irgnm_defaults;
 
 	irgnm_conf.iter = conf->iter;
