@@ -21,10 +21,10 @@ struct noir_conf_s {
 	float b;
 	_Bool pattern_for_each_coil;
 	_Bool sms;
+	unsigned int cnstcoil_flags;
+	_Bool img_space_coils;
 };
 
-
-
 extern const struct noir_conf_s noir_defaults;
 
 extern void noir_recon(const struct noir_conf_s* conf,
