@@ -1,5 +1,5 @@
 /* Copyright 2014-2015. The Regents of the University of California.
- * Copyright 2016-2018. Martin Uecker.
+ * Copyright 2016-2020. Uecker Lab. University Medical Center Göttingen.
  * All rights reserved. Use of this source code is governed by
  * a BSD-style license which can be found in the LICENSE file.
  */
@@ -15,8 +15,10 @@ struct nufft_conf_s {
 	_Bool pcycle; /// < Phase cycling
 	_Bool periodic;
 	_Bool lowmem;
+	int loopdim;
 	unsigned long flags;
 	unsigned long cfft;
+	_Bool decomp;
 };
 
 extern struct nufft_conf_s nufft_conf_defaults;
@@ -55,6 +57,10 @@ extern _Complex float* compute_psf(unsigned int N,
 extern void estimate_im_dims(int N, unsigned long flags, long dims[__VLA(N)], const long tdims[__VLA(N)], const complex float* traj);
 
 extern const struct operator_s* nufft_precond_create(const struct linop_s* nufft_op);
+extern void estimate_fast_sq_im_dims(unsigned int N, 		///< Number of dimensions
+			      long dims[3], 			///< Output estimated image dimensions
+			      const long tdims[N], 		///< Trajectory dimesion
+			      const complex float* traj);	///< Trajectory
 
 #include "misc/cppwrap.h"
 
