@@ -19,6 +19,7 @@
 #include "num/loop.h"
 
 #include "misc/misc.h"
+#include "misc/nested.h"
 
 #include "filter.h"
 
@@ -60,23 +61,7 @@ complex float median_complex_float(int N, const complex float ar[N])
 }
 
 
-struct median_s {
 
-	long length;
-	long stride;
-};
-
-static void nary_medianz(void* _data, void* ptr[])
-{
-	struct median_s* data = (struct median_s*)_data;
-
-	complex float tmp[data->length];
-
-	for (long i = 0; i < data->length; i++)
-		tmp[i] = *((complex float*)(ptr[1] + i * data->stride));
-
-	*(complex float*)ptr[0] = median_complex_float(data->length, tmp);
-}
 
 void md_medianz2(int D, int M, const long dim[D], const long ostr[D], complex float* optr, const long istr[D], const complex float* iptr)
 {
@@ -84,7 +69,8 @@ void md_medianz2(int D, int M, const long dim[D], const long ostr[D], complex fl
 	const long* nstr[2] = { ostr, istr };
 	void* nptr[2] = { optr, (void*)iptr };
 
-	struct median_s data = { dim[M], istr[M] };
+	long length = dim[M];
+	long stride = istr[M];
 
 	long dim2[D];
 	for (int i = 0; i < D; i++)
@@ -92,7 +78,17 @@ void md_medianz2(int D, int M, const long dim[D], const long ostr[D], complex fl
 
 	dim2[M] = 1;
 
-	md_nary(2, D, dim2, nstr, nptr, (void*)&data, &nary_medianz);
+	NESTED(void, nary_medianz, (void* ptr[]))
+	{
+		complex float tmp[length];
+
+		for (long i = 0; i < length; i++)
+			tmp[i] = *((complex float*)(ptr[1] + i * stride));
+
+		*(complex float*)ptr[0] = median_complex_float(length, tmp);
+	};
+
+	md_nary(2, D, dim2, nstr, nptr, nary_medianz);
 }
 
 void md_medianz(int D, int M, const long dim[D], complex float* optr, const complex float* iptr)
