@@ -25,6 +25,11 @@ extern const struct iovec_s* iovec_create2(unsigned int N, const long dims[__VLA
 extern void iovec_free(const struct iovec_s* x);
 extern bool iovec_check(const struct iovec_s* iov, unsigned int N, const long dims[__VLA(N)], const long strs[__VLA(N)]);
 
+
+// in-place initialization and deconstruction
+extern void iovec_init2(struct iovec_s* n, unsigned int N, const long dims[__VLA(N)], const long strs[__VLA(N)], size_t size);
+extern void iovec_destroy(const struct iovec_s* x);
+
 extern void debug_print_iovec(int level, const struct iovec_s* vec);
 
 #include "misc/cppwrap.h"
