@@ -36,7 +36,7 @@ extern const struct sense_conf sense_defaults;
 struct operator_s;
 struct operator_p_s;
 
-extern const struct operator_s* sense_recon_create(const struct sense_conf* conf, const long dims[DIMS],
+extern const struct operator_p_s* sense_recon_create(const struct sense_conf* conf, const long dims[DIMS],
 		  const struct linop_s* sense_op,
 		  const long pat_dims[DIMS], const complex float* pattern,
 		  italgo_fun2_t italgo, iter_conf* iconf,
@@ -44,7 +44,8 @@ extern const struct operator_s* sense_recon_create(const struct sense_conf* conf
 		  unsigned int num_funs,
 		  const struct operator_p_s* thresh_op[num_funs],
 		  const struct linop_s* thresh_funs[num_funs],
-		  const struct operator_s* precond_op);
+		  const struct operator_s* precond_op,
+		  struct iter_monitor_s* monitor);
 
 extern void debug_print_sense_conf(int debug_level, const struct sense_conf* conf);
 
